powered by
Calculate log likelihood function for microbiome sample mixture model at particular values of p and e.
p
e
mbmix_loglik(tab, p, e = 0)
The log likelihood evaluated at p and e.
Dataset of read counts as 3d array of size 3x3x2, genotype in first sample x genotype in second sample x allele in read.
Contaminant probability (proportion of mixture coming from the second sample).
Sequencing error rate.
data(mbmixdata) mbmix_loglik(mbmixdata, p=0.74, e=0.002)
Run the code above in your browser using DataLab